#ifndef YYSTYPE
#define YYSTYPE int
#endif
#define	EXPRESSION_START_	258
#define	COMMAND_START_	259
#define	HISTORY_	260
#define	GEOMVIEW_	261
#define	VIEW_MATRIX_	262
#define	LEAD_INTEGER_	263
#define	INTEGER_	264
#define	REAL_	265
#define	SIGNED_NUMBER_	266
#define	NEWIDENT_	267
#define	REDEFINE_	268
#define	MATHFUNC_	269
#define	MATHFUNC2_	270
#define	POW_	271
#define	USERFUNC_	272
#define	MIDV_	273
#define	DATAFILENAME_	274
#define	LOGFILE_	275
#define	PI_	276
#define	E_	277
#define	G_	278
#define	PARAM_	279
#define	SYMBOL_	280
#define	TOTAL_	281
#define	EXTRA_ATTRIBUTE_	282
#define	FIXEDVOL_	283
#define	IDENT_	284
#define	UMINUS_	285
#define	SHELL_	286
#define	COLOR_	287
#define	HESSIAN_	288
#define	VOLCONST_	289
#define	TORUS_PERIODS_	290
#define	VERTICES_	291
#define	EDGES_	292
#define	FACETS_	293
#define	BODIES_	294
#define	HESSIAN_MENU_	295
#define	POSTSCRIPT_	296
#define	LENGTH_	297
#define	AREA_	298
#define	VOLUME_	299
#define	ID_	300
#define	OID_	301
#define	TAG_	302
#define	ORIGINAL_	303
#define	FACETEDGES_	304
#define	WRAP_	305
#define	QUOTATION_	306
#define	UNSET_	307
#define	TOPINFO_	308
#define	OPACITY_	309
#define	VALENCE_	310
#define	HESSIAN_SADDLE_	311
#define	SET_	312
#define	FIXED_	313
#define	DENSITY_	314
#define	PRESSURE_	315
#define	CONSTRAINT_	316
#define	COORD_	317
#define	DISSOLVE_	318
#define	WHERE_	319
#define	LIST_	320
#define	SHOW_	321
#define	DELETE_	322
#define	REFINE_	323
#define	RECALC_	324
#define	SHOWQ_	325
#define	EDGESWAP_	326
#define	FIX_	327
#define	UNFIX_	328
#define	TOGGLENAME_	329
#define	TOGGLEVALUE_	330
#define	STAR_	331
#define	QUANTITY_NAME_	332
#define	PAUSE_	333
#define	GO_	334
#define	SHOW_VOL_	335
#define	CHECK_	336
#define	READ_	337
#define	ZOOM_	338
#define	ON_	339
#define	OFF_	340
#define	GEOMPIPE_	341
#define	SELF_	342
#define	SINGLE_LETTER_	343
#define	LONG_JIGGLE_	344
#define	RAW_VERAVG_	345
#define	COUNTS_	346
#define	CHDIR_	347
#define	ALICE_	348
#define	STABILITY_TEST_	349
#define	DEFINE_	350
#define	UPLUS_	351
#define	DATATYPE_	352
#define	FLUSH_COUNTS_	353
#define	AUTOCHOP_	354
#define	UTEST_	355
#define	ATTRIBUTE_	356
#define	RITZ_	357
#define	MOVE_	358
#define	VERTEXNORMAL_	359
#define	POP_	360
#define	SYSTEM_	361
#define	TETRA_POINT_	362
#define	TRIPLE_POINT_	363
#define	LANCZOS_	364
#define	EIGENPROBE_	365
#define	EXEC_	366
#define	AREAWEED_	367
#define	EDGEWEED_	368
#define	GRAVITY_	369
#define	EDGEDIVIDE_	370
#define	LINEAR_	371
#define	QUADRATIC_	372
#define	DIFFUSION_	373
#define	EXTRAPOLATE_	374
#define	TRANSFORM_DEPTH_	375
#define	PRINTF_	376
#define	ERRPRINTF_	377
#define	PRINT_	378
#define	MAX_	379
#define	MIN_	380
#define	COUNT_	381
#define	SUM_	382
#define	AVG_	383
#define	BREAK_	384
#define	CONTINUE_	385
#define	SIZEOF_	386
#define	TRANSFORM_EXPR_	387
#define	BARE_	388
#define	BOTTOMINFO_	389
#define	METIS_	390
#define	KMETIS_	391
#define	KEYLOGFILE_	392
#define	SCALE_	393
#define	BURCHARD_	394
#define	REBODY_	395
#define	BOUNDARY_	396
#define	ORIENTATION_	397
#define	OMETIS_	398
#define	SQ_MEAN_CURV_	399
#define	FRONTCOLOR_	400
#define	SINGLE_REDEFD_	401
#define	METHOD_NAME_	402
#define	NODE_EXEC_	403
#define	RAWEST_VERAVG_	404
#define	SINGLE_LETTER_ARG_	405
#define	BACKCOLOR_	406
#define	LAGRANGE_	407
#define	RETURN_	408
#define	TRANSFORM_EXPR_VERB_	409
#define	OOGLFILE_	410
#define	MEAN_CURVATURE_	411
#define	PARALLEL_EXEC_	412
#define	SPRINTF_	413
#define	CONVERT_TO_QUANTS_	414
#define	METIS_FACTOR_	415
#define	FUNCTION_	416
#define	EXPRINT_	417
#define	DIHEDRAL_	418
#define	WRAP_VERTEX_	419
#define	ARRAYIDENT_	420
#define	DATE_AND_TIME_	421
#define	LOCAL_	422
#define	SHOW_EXPR_	423
#define	SHOW_TRANS_	424
#define	AXIAL_POINT_	425
#define	ENERGY_	426
#define	CONSERVED_	427
#define	INFO_ONLY_	428
#define	ASSIGN_	429
#define	PROCEDURE_	430
#define	FOREACH_	431
#define	STRINGGLOBAL_	432
#define	EQUIANGULATE_	433
#define	HISTOGRAM_	434
#define	LOGHISTOGRAM_	435
#define	AREA_FIXED_	436
#define	QUIT_	437
#define	WARNING_MESSAGES_	438
#define	IF_	439
#define	WHILE_	440
#define	DO_	441
#define	NO_REFINE_	442
#define	STRING_	443
#define	NONCONTENT_	444
#define	FOR_	445
#define	HIT_PARTNER_	446
#define	FRONTBODY_	447
#define	BACKBODY_	448
#define	COLORFILE_	449
#define	PERM_STRINGGLOBAL_	450
#define	FUNCTION_IDENT_	451
#define	THICKEN_	452
#define	COLORMAP_	453
#define	REDIRECT_	454
#define	NEWVERTEX_	455
#define	NEWEDGE_	456
#define	NEWFACET_	457
#define	MODULUS_	458
#define	TARGET_	459
#define	VALUE_	460
#define	INVERSE_PERIODS_	461
#define	NEWBODY_	462
#define	DELTA_	463
#define	GAP_CONSTANT_	464
#define	DUMP_	465
#define	NOTCH_	466
#define	QUANTITY_	467
#define	LOAD_	468
#define	PERM_PROCEDURE_	469
#define	PROCEDURE_WORD_	470
#define	DYNAMIC_LOAD_FUNC_	471
#define	PERM_IDENT_	472
#define	PERMLOAD_	473
#define	HELP_	474
#define	VERTEX_AVERAGE_	475
#define	METHOD_INSTANCE_	476
#define	RAW_VERTEX_AVERAGE_	477
#define	OPTIMIZE_	478
#define	REDIRECTOVER_	479
#define	TOLERANCE_	480
#define	RAWEST_VERTEX_AVERAGE_	481
#define	JIGGLE_	482
#define	VIEW_TRANSFORMS_	483
#define	CLOSE_SHOW_	484
#define	IS_DEFINED_	485
#define	NODISPLAY_	486
#define	PERM_ASSIGN_	487
#define	PHASE_	488
#define	VIEW_TRANSFORM_SWAP_COLORS_	489
#define	BACKQUOTE_COMMA_	490
#define	INTERNAL_VARIABLE_	491
#define	DIRICHLET_	492
#define	SOBOLEV_	493
#define	VIEW_TRANSFORM_PARITY_	494
#define	SOBOLEV_SEEK_	495
#define	DIRICHLET_SEEK_	496
#define	HESSIAN_SEEK_	497
#define	REORDER_STORAGE_	498
#define	RENUMBER_ALL_	499
#define	CONSTRAINT_NAME_	500
#define	BOUNDARY_NAME_	501
#define	PROCEDURE_IDENT_	502
#define	POP_TRI_TO_EDGE_	503
#define	POP_EDGE_TO_TRI_	504
#define	POP_QUAD_TO_QUAD_	505
#define	SHOWVERB_	506
#define	PROCEDURES_	507
#define	MPI_TASK_ATTR_	508
#define	T1_EDGESWAP_	509
#define	MERGE_EDGE_	510
#define	MERGE_FACET_	511
#define	MERGE_VERTEX_	512
#define	RESET_COUNTS_	513
#define	VALID_ELEMENT_	514
#define	MID_EDGE_	515
#define	MID_FACET_	516
#define	GO_COUNT_	517
#define	ELEMENT_IDENT_	518
#define	BODY_METIS_	519
#define	REVERSE_ORIENTATION_	520
#define	MATRIX_MULTIPLY_	521
#define	MATRIX_INVERSE_	522
#define	BINARY_PRINTF_	523
#define	DUMP_MEMLIST_	524
#define	FREE_DISCARDS_	525
#define	ASSIGNOP_	526
#define	PIPE_	527
#define	THEN_	528
#define	ELSE_	529
#define	OR_	530
#define	AND_	531
#define	NOT_	532
#define	EQ_	533
#define	LE_	534
#define	GE_	535
#define	NE_	536
#define	ON_CONSTRAINT_	537
#define	HIT_CONSTRAINT_	538
#define	ON_BOUNDARY_	539
#define	ON_QUANTITY_	540
#define	ON_METHOD_INSTANCE_	541
#define	IMOD_	542
#define	IDIV_	543
#define	EPRINT_	544

